mirthsync.xml


add-update-childclj

(add-update-child root-loc child-loc)

Adds or updates (by ID) an child element within the supplied root. Assumes that the typical mirth xml structure is present with a root collection element and an ID element within the child.

Adds or updates (by ID) an child element within the supplied root. Assumes that
the typical mirth xml structure is present with a root collection element
and an ID element within the child.
raw docstring

serialize-nodeclj

(serialize-node {:keys [api el-loc restrict-to-path target disk-mode]
                 :as app-conf})

Take an xml location and write to the filesystem with a meaningful name and path. If the file exists it is not overwritten unless the -f option is set. Unordered collections are sorted first unless --no-sort-unordered is set. Returns app-conf.

Take an xml location and write to the filesystem with a meaningful
name and path. If the file exists it is not overwritten unless the
-f option is set. Unordered collections are sorted first unless
--no-sort-unordered is set. Returns app-conf.
raw docstring

sort-unorderedclj

(sort-unordered node)
(sort-unordered ancestors node)

Returns the xml element with the children of every element listed in unordered-paths sorted. Children are sorted bottom-up so nested sets are already canonical when compared.

Returns the xml element with the children of every element listed in
unordered-paths sorted. Children are sorted bottom-up so nested sets are
already canonical when compared.
raw docstring

to-zipclj

(to-zip x)

Takes a string of xml and returns an xml zipper

Takes a string of xml and returns an xml zipper
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries